# LTSpiceXVII Benchmark Script
#
# E. Sims 3/29/2020
# Udo Krebelder <udo.krebelder@gmx.at> 10/02/2022
#

# List of LTSpice test files
$files = @( 'mux8.cir',
            'mike2.cir',
            'bjtff.cir',
            'AzurAmp.asc',
            'MonteCarlo.asc',
            'LT3845_TA01.asc',
            'BuckBoost.asc',
            'SettleTime.asc',
            'Electrometer.asc',
            'AudioChannels16.asc',
            'OscillatorQuadrature.asc' )

# LTSpice executable, standard location
$LTSpice= "C:\Program Files\LTC\LTspiceXVII\XVIIx64.exe"

if (!(Test-Path $LTSpice)) {
    # LTSpice exe, alternate location
    $LTSpice= "C:\Program Files\LTspiceXVII\XVIIx64.exe"
}

if (!(Test-Path $LTSpice)) {
    Write-Error "Cannot find LTSpice executable" -ErrorAction Stop
}

$ver = [Diagnostics.FileVersionInfo]::GetVersionInfo($LTSpice)

$date = date
Write-Output ('LTSpice ' + $ver.ProductVersion + ' Benchmark')
Write-Output ''
Write-Output 'CPU Info...'
$proc = Get-WmiObject -Class Win32_Processor | Select-Object -Property Name, NumberOfCores, NumberOfLogicalProcessors
($proc | Out-String).Trim() | Write-Output
Write-Output ''

$runs = @()
$totaltime = 0

foreach($file in $files)
{
    Write-Output ('Running ' + $file + ': ')

    $b = (Get-Item $file).basename
    $l = $b + '.log'
    if (Test-Path $l) { Remove-Item $l }

    # time2 is the execution time
    #$time2 = (Measure-Command {cmd /c 'XVIIx64.exe' -b -run $file}).TotalSeconds
    Start-Process -FilePath $LTSpice -Wait -ArgumentList "-b -run $file"

    # time is the simulation time from the log file
    $f = (Select-String -path $l -pattern "Total elapsed time:")
    $a = @($f -split ' ')
    $time = $a[3]

    $runs += [pscustomobject]@{'File'=$file;'ExecTime'=[math]::round($time,1)}

    $totaltime += $time
    Write-Output ('  ' + [math]::round($time,1) + ' seconds')
    Write-Output ''
    Start-Sleep -m 100

    $f = $b + '.net'
    if (Test-Path $f) { Remove-Item $f }

    $f = $b + '.raw'
    if (Test-Path $f) { Remove-Item $f }

    $f = $b + '.op.raw'
    if (Test-Path $f) { Remove-Item $f }
}

Write-Output ('Total time: ' + [math]::round($totaltime,1) + ' seconds')
Write-Output ''

$logfile = 'LTSpiceBenchmarkReport.txt'

if (!(Test-Path $logfile)) { New-Item -Path . -Name $logfile -ItemType "file" }

Add-Content -Path $logfile '********************************************************************************'
Add-Content -Path $logfile ('LTSpice ' + $ver.ProductVersion + ' Benchmark')
Add-Content -Path $logfile ($env:computername + ' ' + $date)
Add-Content -Path $logfile ''

($proc | Out-String).Trim() | Out-File $logfile -Append -Encoding ASCII
Add-Content -Path $logfile ''

($runs | Select-Object -Property File,ExecTime | Out-String).Trim() | Out-File $logfile -Append -Encoding ASCII
Add-Content -Path $logfile ''

Add-Content -Path $logfile ('Total time: ' + [math]::round($totaltime,1) + ' seconds')
Add-Content -Path $logfile ''
Add-Content -Path $logfile ''

#pause
